import { Redis } from 'ioredis';
import { config } from './config.ts';

type initRedisOpts = {
  onConnect?: () => void; // 连接成功的回调函数
  onError?: (msg?: any) => void; // 连接断开的回调函数
};
const initRedis = (config?: any, options?: initRedisOpts) => {
  const redis = new Redis({
    host: config?.REDIS_HOST || 'localhost', // Redis 服务器的主机名或 IP 地址
    port: config?.REDIS_PORT || 6379, // Redis 服务器的端口号
    // password: 'your_password', // Redis 的密码 (如果有)
    db: 0, // 要使用的 Redis 数据库索引 (0-15)
    keyPrefix: '', // key 前缀
    retryStrategy(times) {
      // 连接重试策略
      return Math.min(times * 50, 2000); // 每次重试时延迟增加
    },
    maxRetriesPerRequest: null, // 允许请求重试的次数 (如果需要无限次重试)
    ...config, // 其他配置项
  });
  // 监听连接事件
  redis.on('connect', () => {
    if (options?.onConnect) {
      options.onConnect();
      console.log('Redis 连接成功');
    }
  });

  redis.on('error', (err) => {
    console.error('Redis 连接错误', err);
    if (options?.onError) {
      options.onError(err);
    }
  });
  return redis;
};
// 配置 Redis 连接
export const redis = useConfigKey('redis', () => initRedis(config));

// 初始化 Redis 客户端
export const redisPublisher = new Redis(); // 用于发布消息
export const redisSubscriber = new Redis(); // 用于订阅消息
